sqlobject.tests.test_validation module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_validation module

class `sqlobject.tests.test_validation.` `SOTestValidator`(*args, **kw)

  Bases: `formencode.api.Validator`

  Messages

  `declarative_count` = 396
  `from_python`(value, state)
  `to_python`(value, state)

class `sqlobject.tests.test_validation.` `SOValidation`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_validation
  property `name`
  property `name2`
  property `name3`
  property `name4`
  property `name5`
  property `name6`
  property `name7`
  property `name8`
  property `name9`
  `q` = so_validation
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_validation.SOValidation`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_validation'

class `sqlobject.tests.test_validation.` `SOValidationTest`(value)

  Bases: `object`

class `sqlobject.tests.test_validation.` `SOValidationTestBool`(value)

  Bases: `sqlobject.tests.test_validation.SOValidationTest`

class `sqlobject.tests.test_validation.` `SOValidationTestFloat`(value)

  Bases: `sqlobject.tests.test_validation.SOValidationTest`

class `sqlobject.tests.test_validation.` `SOValidationTestInt`(value)

  Bases: `sqlobject.tests.test_validation.SOValidationTest`

class `sqlobject.tests.test_validation.` `TestValidation`

  Bases: `object`

  `setup_method`(meth)
  `test_confirmType`()
  `test_emptyValue`()
  `test_validate`()
  `test_validator2`()
  `test_wrapType`()